==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>Pas de frontière sélectionnée.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Contour pas fermé au point %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Chaque objet frontière doit être une ligne, arc, cercle, un arc elliptique, ellipse, polyligne ou une spline. Trouvés:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Hachure</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Dessinez une hachure ou un remplissage uni</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Hachure</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Remplissage uni</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Motif hachure</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Motif</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Echelle :</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">Pas de frontière sélectionnée.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Contour pas fermé au point %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Chaque objet frontière doit être une ligne, arc, cercle, un arc elliptique, ellipse, polyligne ou une spline. Trouvés:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Outils hachure</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Afficher les outils hachure</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Hachure</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Dessinez une hachure ou un remplissage uni</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Hachure</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Remplissage uni</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Motif hachure</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Motif</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Angle :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Echelle :</translation>
    </message>
</context>
</TS>
